from setuptools import setup

setup(name='braga',
      version='0.1',
      description='Toy Entity-Component system',
      url='http://github.com/astrosilverio/braga',
      author='astrosilverio',
      author_email='astrosilverio@gmail.com',
      license='MIT',
      packages=['braga'],
      zip_safe=False)
